# Technology Standards Management Capabilities
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/technology-standards-management-capabilities#introduction)
  * [Technology Standards Management Capabilities](https://help.sap.com/docs/leanix/ea/technology-standards-management-capabilities#technology-standards-management-capabilities)
  * [Getting Started](https://help.sap.com/docs/leanix/ea/technology-standards-management-capabilities#getting-started)


SAP LeanIX Technology Risk and Compliance facilitates inventorizing the technology landscape, provides comprehensive visibility, and helps you derive data-driven decisions to standardize the technology landscape.
